@@ -1,34 +1,27 @@
 ﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import time, re, os
+import re 
 from QonsoExtractor import QonsoExtractor
-from PyQt4 import QtWebKit, QtCore, QtGui
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply, QNetworkProxy, QNetworkCookieJar
+from PyQt4 import QtCore
+from PyQt4.QtNetwork import QNetworkRequest
 
 class QonsoExtractorBouygues(QonsoExtractor):
-   def __init__(self, view):
-      self.debug = os.environ.has_key('DEBUG')
-      QonsoExtractor.__init__(self, view)
+   def __init__(self):
+      QonsoExtractor.__init__(self)
+      
       self.urlconso = "http://www.espaceclient.bouyguestelecom.fr/ECF/jsf/client/conso-factures/details-conso/viewDetailsConso.jsf"
       self.urlbeforeAuth = "https://www.espaceclient.bouyguestelecom.fr/ECF/jsf/submitLogin.jsf"
       self.urlAuth = "https://www.espaceclient.bouyguestelecom.fr/ECF/jsf/j_security_check;jsessionId="
       self.hostname = "www.espaceclient.bouyguestelecom.fr"
-      self.i = 1
 
    def Authenticate(self, idCorrelation):
       self.SetStatus('INFO', 'Authentification...')
 
-      request = QNetworkRequest()
+      request = self.PrepareRequest()
       request.setUrl( QtCore.QUrl(self.urlAuth+idCorrelation) ) 
-      request.setHeader(QNetworkRequest.ContentTypeHeader, "application/x-www-form-urlencoded")
-      request.setRawHeader("Connection", "keep-alive")
-      request.setRawHeader("Keep-Alive", "115");
-      request.setRawHeader("Referer", self.urlbeforeAuth)
-      request.setRawHeader("Host", self.hostname)
       
       cookies = self.manager.cookieJar().cookiesForUrl(QtCore.QUrl("http://"+self.hostname))
-
       for cookie in cookies:
          if cookie.name()=="JSESSIONID":
             request.setRawHeader("Cookie", "testcookie; "+cookie.name()+"="+cookie.value())
@@ -39,12 +32,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
       params.addQueryItem("application_name", "ESPACE_CLIENT_WEB_FORFAIT")
       params.addQueryItem("idCorrelation", idCorrelation)
 
-      postData = QtCore.QByteArray()
-      postData.append(params.toString()[1:])
-
-      request.setRawHeader("Content-Length", "%s" % postData.length() )
-   
-      self.manager.post(request, postData)
+      self.PostRequest(params, request)
       
    def DoReadResponse(self, reply):
       request = QNetworkRequest()
