@@ -1,45 +1,37 @@
 ﻿#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import time, re
+import re
 from QonsoExtractor import QonsoExtractor
-from PyQt4 import QtWebKit, QtCore, QtGui
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply, QNetworkProxy, QNetworkCookieJar
+from PyQt4 import QtCore
+from PyQt4.QtNetwork import QNetworkRequest
 
 class QonsoExtractorSFR(QonsoExtractor):
-   def __init__(self, view):
-      self.view = view
-      QonsoExtractor.__init__(self, view)
-      self.SetStatus('INFO', "Initialisation...")
+   def __init__(self):
+      QonsoExtractor.__init__(self)
+      
+      # URL de la page d'info conso
       self.urlconso = "https://monprofil.sfr.fr/monprofilWEBV5/Accueil?acces=enc"
+      
+      # URL présentant le formulaire pour la connection au compte
       self.urlbeforeAuth = "https://www.sfr.fr/cas/login?domain=mon-compte"
+      
+      # URL où on envoie la requête POST pour l'authentification, en général, elle est dans le form 
       self.urlAuth = "https://www.sfr.fr/cas/login?domain=mon-compte&service=https%3A%2F%2Fwww.sfr.fr%2Fj_spring_cas_security_check"
+      
       self.hostname = "www.sfr.fr"
       
    def Authenticate(self):
       self.SetStatus('INFO', 'Authentification...')
 
-      request = QNetworkRequest()
-      request.setUrl( QtCore.QUrl(self.urlAuth) ) 
-      request.setHeader(QNetworkRequest.ContentTypeHeader, "application/x-www-form-urlencoded")
-      request.setRawHeader("Connection", "keep-alive")
-      request.setRawHeader("Keep-Alive", "115");
-      request.setRawHeader("Referer", self.urlbeforeAuth)
-      request.setRawHeader("Host", self.hostname)
-      
-      cookies = self.manager.cookieJar().cookiesForUrl(QtCore.QUrl("http://"+self.hostname))
-
       params = QtCore.QUrl()
+      # Mettre ici les paramètres du formulaire (login, password, champs cachés)
       params.addQueryItem("username", self.login)
       params.addQueryItem("password", self.password)
       params.addQueryItem("internal", "W")
-
-      postData = QtCore.QByteArray()
-      postData.append(params.toString()[1:])
-
-      request.setRawHeader("Content-Length", "%s" % postData.length() )
-   
-      self.manager.post(request, postData)
+      #
+      
+      self.PostRequest(params)
       
    def DoReadResponse(self, reply):
       request = QNetworkRequest()
@@ -53,6 +45,7 @@ class QonsoExtractorSFR(QonsoExtractor):
       elif self.authentication == 'InProgress':
          html = reply.readAll()
          self.frame.setHtml(str(html))
+         # Gestion des erreurs, retrouver l'erreur sur la page et la mettre dans le status
          errors = self.frame.findAllElements('p[class="error"]')
 
          if errors:
@@ -66,6 +59,7 @@ class QonsoExtractorSFR(QonsoExtractor):
             self.authentication = 'Done'
             self.manager.get(request)
 
+   # Extraction des données, dépend de chaque opérateur
    def ExtractDatas(self, datas):
       self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
       self.frame.setHtml( str(datas) )
